@@ -14,8 +14,6 @@ struct Context {
     usage: String,
     author: String,
     all_args: String,
-    unified: String,
-    flags: String,
     options: String,
     positionals: String,
     subcommands: String,
@@ -51,8 +49,6 @@ impl<'a> Context {
             author: existing::existing(app, "{mit}"),
             usage: existing::existing(app, "{usage}"),
             all_args: existing::existing(app, "{all-args}"),
-            unified: existing::existing(app, "{unified}"),
-            flags: existing::existing(app, "{flags}"),
             options: existing::existing(app, "{options}"),
             positionals: existing::existing(app, "{positionals}"),
             subcommands: existing::existing(app, "{subcommands}"),
